-----------------------------------------------------------------------------------------------
-- Client Lua Script for MedalTracker
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
 
-----------------------------------------------------------------------------------------------
-- MedalTracker Module Definition
-----------------------------------------------------------------------------------------------
local MedalTracker = {} 
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
local tMedalAchievsDng = {
	-- Skullcano
	"Bronze Medal: Skullcano (Prime)",
	"Silver Medal: Skullcano (Prime)",
	"Gold Medal: Skullcano (Prime)",
	-- Stormtalon's Lair
	"Bronze Medal: Stormtalon's Lair (Prime)",
	"Silver Medal: Stormtalon's Lair (Prime)",
	"Gold Medal: Stormtalon's Lair (Prime)",
	-- Sanctuary of the Swordmaiden
	"Bronze Medal: Sanctuary of the Swordmaiden (Prime)",
	"Silver Medal: Sanctuary of the Swordmaiden (Prime)",
	"Gold Medal: Sanctuary of the Swordmaiden (Prime)",
	-- Ruins of Kel Voreth
	"Bronze Medal: The Ruins of Kel Voreth (Prime)",
	"Silver Medal: The Ruins of Kel Voreth (Prime)",
	"Gold Medal: The Ruins of Kel Voreth (Prime)",
	-- Protogames Academy
	"Bronze Medal: Protogames Academy (Prime)",
	"Silver Medal: Protogames Academy (Prime)",
	"Ultimate Protogames Champion",
	-- Ultimate Protogames
	"Bronze Protogames Star",
	"Silver Protogames Star",
	"Ultimate Protogames Champion",
	-- Coldblood Citadel
	"Bronze Medal: Coldblood Citadel (Prime)",
	"Silver Medal: Coldblood Citadel (Prime)",
	"Gold Medal: Coldblood Citadel (Prime)"
}
local tMedalAchievsExp = {
	-- Infestation
	"Expedition: Infestation (Prime)",
	"Gold Medal: Infestation (Prime)",
	-- Rage Logic 
	"Expedition: Rage Logic (Prime)",
	"Gold Medal: Rage Logic (Prime)",
	-- Space Madness 
	"Expedition: Space Madness (Prime)",
	"Gold Medal: Space Madness (Prime)",
	-- Outpost M-13
	"Expedition: Outpost M-13 (Prime)",
	"Gold Medal: Outpost M-13 (Prime)",
	-- Deep Space Exploration 
	"Expedition: Deep Space Exploration (Prime)",
	"Gold Medal: Deep Space Exploration (Prime)",
	-- The Gauntlet
	"Expedition: The Gauntlet (Prime)",
	"Gold Medal: The Gauntlet (Prime)",
	-- They Came from Fragment Zero! 
	"Expedition: They Came from Fragment Zero! (Prime)",
	"Gold Medal: They Came from Fragment Zero! (Prime)",
	-- Evil from the Ether 
	"Expedition: Evil from the Ether (Prime)",
	"Gold Medal: Evil from the Ether (Prime)"
}
local tMedalAchievsAdv = {
	-- The Malgrave Trail
	"Veteran Survivalist",
	"Veteran Trailhand",
	"Caravan Master",
	-- Crimelords of Whitevale
	"Veteran Criminal",
	"Veteran Crimelord",
	"Don",
	-- The Siege of Tempest Refuge
	"Veteran Defender",
	"Veteran Guardian",
	"Decorated Veteran",
	-- War of the Wilds
	"Good Riddance!",
	"Moodie Masher",
	"Skeech Master",
	-- Bay of Betrayal
	"Competent Competitor",
	"Adequate Assassin",
	"Best in the Bay",
}

local tColours = {
	gold   = "Golden",
	silver = "xkcdSilver",
	bronze = "xkcdBronze",
	none = "white"
}

local tMedals = {
	gold = "Gold Medal",
	silver = "Silver Medal",
	bronze = "Bronze Medal",
	none = "No Medal"
}

local tDoneDungeons = {}
local tDoneShiphands = {}
local tDoneAdventures = {}

-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function MedalTracker:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here

    return o
end

function MedalTracker:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 

-----------------------------------------------------------------------------------------------
-- MedalTracker OnLoad
-----------------------------------------------------------------------------------------------
function MedalTracker:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("MedalTracker.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
end

-----------------------------------------------------------------------------------------------
-- MedalTracker OnDocLoaded
-----------------------------------------------------------------------------------------------
function MedalTracker:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "MedalTrackerForm", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		
	    self.wndMain:Show(false, true)

		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
		Apollo.RegisterSlashCommand("medaltracker", "OnMedalTrackerOn", self)
		Apollo.RegisterSlashCommand("mt", "OnMedalTrackerOn", self)
		Apollo.RegisterSlashCommand("mtracker", "OnMedalTrackerOn", self)


		-- Do additional Addon initialization here
		self.debug = true
	end
end

-----------------------------------------------------------------------------------------------
-- MedalTracker Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here

-- on SlashCommand "/medaltracker"
function MedalTracker:OnMedalTrackerOn()
	self.wndMain:Invoke() -- show the window
	MedalTracker:GetAllMedals()
	MedalTracker:DrawAllMedals(self.wndMain)
end

-- get all medals
function MedalTracker:GetAllMedals()
	MedalTracker:GetAdvMedals()
	MedalTracker:GetDngMedals()
	MedalTracker:GetExpMedals()
end

-- draw all medals
function MedalTracker:DrawAllMedals(mainWnd)
	MedalTracker:DrawDngMedals(mainWnd)
	MedalTracker:DrawExpMedals(mainWnd)
	MedalTracker:DrawAdvMedals(mainWnd)
end

function MedalTracker:Debug(msg)
	if self.debug == false then return end
	Print(msg)
end

-- load dungeon medals
function MedalTracker:GetDngMedals()
	local tAchievements = AchievementsLib.GetAchievementsForCategory(65, true, false)
	for idx = 1, #tAchievements do
    	local achCurrent = tAchievements[idx]
		for idy = 1, #tMedalAchievsDng do
			if tMedalAchievsDng[idy] == achCurrent:GetName() and achCurrent:IsComplete() then
				table.insert(tDoneDungeons, tMedalAchievsDng[idy])
			end
		end
	end
end

-- load expedition medals
function MedalTracker:GetExpMedals()
	local tAchievements = AchievementsLib.GetAchievementsForCategory(162, true, false)
	for idx = 1, #tAchievements do
    	local achCurrent = tAchievements[idx]
		for idy = 1, #tMedalAchievsExp do
			if tMedalAchievsExp[idy] == achCurrent:GetName() and achCurrent:IsComplete() then
				table.insert(tDoneShiphands, tMedalAchievsExp[idy])
			end
		end
	end
end

-- load adventure medals
function MedalTracker:GetAdvMedals()
	local tAchievements = AchievementsLib.GetAchievementsForCategory(78, true, false)
	for idx = 1, #tAchievements do
    	local achCurrent = tAchievements[idx]
		for idy = 1, #tMedalAchievsAdv do
			if tMedalAchievsAdv[idy] == achCurrent:GetName() and achCurrent:IsComplete() then
				table.insert(tDoneAdventures, tMedalAchievsAdv[idy])
			end
		end
	end
end

-- populates dungeon medals list
function MedalTracker:DrawDngMedals(mainForm)		
	local medals = {
		pa = "none",
		up = "none",
		sc = "none",
		stl = "none",
		kv = "none",
		ssm = "none",
		cbc = "none"
	}
	
	for idx = 1, #tDoneDungeons do
    	local achCurrent = tDoneDungeons[idx]
		if string.find(achCurrent, "Bronze") ~= nil then
			if string.find(achCurrent,     "Academy")     ~= nil and medals.pa  ~= "gold" and medals.pa  ~= "silver" then medals.pa  = "bronze"
			elseif string.find(achCurrent, "Skullcano")   ~= nil and medals.sc  ~= "gold" and medals.sc  ~= "silver" then medals.sc  = "bronze"
			elseif string.find(achCurrent, "Lair")        ~= nil and medals.stl ~= "gold" and medals.stl ~= "silver" then medals.stl = "bronze"
			elseif string.find(achCurrent, "Ruins")       ~= nil and medals.kv  ~= "gold" and medals.kv  ~= "silver" then medals.kv  = "bronze"
			elseif string.find(achCurrent, "Swordmaiden") ~= nil and medals.ssm ~= "gold" and medals.ssm ~= "silver" then medals.ssm = "bronze"
			elseif string.find(achCurrent, "Coldblood")   ~= nil and medals.cbc ~= "gold" and medals.cbc ~= "silver" then medals.cbc = "bronze"
			elseif string.find(achCurrent, "Star")    ~= nil and medals.up  ~= "gold" and medals.up  ~= "silver" then medals.up  = "bronze"
			end
		elseif string.find(achCurrent, "Silver") ~= nil then
			if string.find(achCurrent,     "Academy")     ~= nil and medals.pa  ~= "gold" then medals.pa  = "silver"
			elseif string.find(achCurrent, "Skullcano")   ~= nil and medals.sc  ~= "gold" then medals.sc  = "silver"
			elseif string.find(achCurrent, "Lair")        ~= nil and medals.stl ~= "gold" then medals.stl = "silver"
			elseif string.find(achCurrent, "Ruins")      ~= nil and medals.kv  ~= "gold" then medals.kv  = "silver"
			elseif string.find(achCurrent, "Swordmaiden") ~= nil and medals.ssm ~= "gold" then medals.ssm = "silver"
			elseif string.find(achCurrent, "Coldblood")   ~= nil and medals.cbc ~= "gold" then medals.cbc = "silver"
			elseif string.find(achCurrent, "Star")    ~= nil and medals.up  ~= "gold" then medals.up  = "silver"
			end
		elseif string.find(achCurrent, "Gold") ~= nil then
			if string.find(achCurrent,     "Academy")     ~= nil then medals.pa  = "gold"
			elseif string.find(achCurrent, "Skullcano")   ~= nil then medals.sc  = "gold"
			elseif string.find(achCurrent, "Lair")        ~= nil then medals.stl = "gold"
			elseif string.find(achCurrent, "Ruins")       ~= nil then medals.kv  = "gold"
			elseif string.find(achCurrent, "Swordmaiden") ~= nil then medals.ssm = "gold"
			elseif string.find(achCurrent, "Coldblood")   ~= nil then medals.cbc = "gold"
			
			end
		elseif string.find(achCurrent, "Champion") ~= nil then
			if string.find(achCurrent, "Ultimate") ~= nil then medals.up  = "gold" end
		end
	end
	
	local dngWnd = mainForm:FindChild("Dungeons")
	if dngWnd == nil then
		Apollo.AddAddonErrorText(self, "Could not load the dungeons sub-window for some reason.")
		return
	end
	
	local txtMedal = dngWnd:FindChild("PA"):FindChild("Medal")
	if medals.pa == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.pa == "silver" then 
		txtMedal:SetText(tMedals.silver)
		txtMedal:SetTextColor(tColours.silver)
	elseif medals.pa == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
	
	txtMedal = dngWnd:FindChild("SC"):FindChild("Medal")
	if medals.sc == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.sc == "silver" then 
		txtMedal:SetText(tMedals.silver)
		txtMedal:SetTextColor(tColours.silver)
	elseif medals.sc == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
	
	txtMedal = dngWnd:FindChild("KV"):FindChild("Medal")
	if medals.kv == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.kv == "silver" then 
		txtMedal:SetText(tMedals.silver)
		txtMedal:SetTextColor(tColours.silver)
	elseif medals.kv == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
	
	txtMedal = dngWnd:FindChild("STL"):FindChild("Medal")
	if medals.stl == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.stl == "silver" then 
		txtMedal:SetText(tMedals.silver)
		txtMedal:SetTextColor(tColours.silver)
	elseif medals.stl == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
	
	txtMedal = dngWnd:FindChild("SSM"):FindChild("Medal")
	if medals.ssm == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.ssm == "silver" then 
		txtMedal:SetText(tMedals.silver)
		txtMedal:SetTextColor(tColours.silver)
	elseif medals.ssm == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
	
	txtMedal = dngWnd:FindChild("CBC"):FindChild("Medal")
	if medals.cbc == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.cbc == "silver" then 
		txtMedal:SetText(tMedals.silver)
		txtMedal:SetTextColor(tColours.silver)
	elseif medals.cbc == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
	
	txtMedal = dngWnd:FindChild("UP"):FindChild("Medal")
	if medals.up == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.up == "silver" then 
		txtMedal:SetText(tMedals.silver)
		txtMedal:SetTextColor(tColours.silver)
	elseif medals.up == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
end

-- populates expedition medals list
function MedalTracker:DrawExpMedals(mainForm)
	local medals = {
		f0 = "none",
		sm = "none",
		gnt = "none",
		rl = "none",
		dse = "none",
		inf = "none",
		ee = "none",
		m13 = "none"
	}
	
	for idx = 1, #tDoneShiphands do
    	local achCurrent = tDoneShiphands[idx]
		if string.find(achCurrent, "Expedition") ~= nil then
			if string.find(achCurrent,     "Fragment")    ~= nil and medals.f0  ~= "gold" then medals.f0  = "bronze"
			elseif string.find(achCurrent, "Madness")     ~= nil and medals.sm  ~= "gold" then medals.sm  = "bronze"
			elseif string.find(achCurrent, "Gauntlet")    ~= nil and medals.gnt ~= "gold" then medals.gnt = "bronze"
			elseif string.find(achCurrent, "Rage")        ~= nil and medals.rl  ~= "gold" then medals.rl  = "bronze"
			elseif string.find(achCurrent, "Deep")        ~= nil and medals.dse ~= "gold" then medals.dse = "bronze"
			elseif string.find(achCurrent, "Infestation") ~= nil and medals.inf ~= "gold" then medals.inf = "bronze"
			elseif string.find(achCurrent, "Ether")       ~= nil and medals.ee  ~= "gold" then medals.ee  = "bronze"
			elseif string.find(achCurrent, "Outpost")     ~= nil and medals.m13 ~= "gold" then medals.m13 = "bronze"		
			end
		elseif string.find(achCurrent, "Gold") ~= nil then
			if string.find(achCurrent,     "Fragment")    ~= nil then medals.f0  = "gold"
			elseif string.find(achCurrent, "Madness")     ~= nil then medals.sm  = "gold"
			elseif string.find(achCurrent, "Gauntlet")    ~= nil then medals.gnt = "gold"
			elseif string.find(achCurrent, "Rage")        ~= nil then medals.rl  = "gold"
			elseif string.find(achCurrent, "Deep")        ~= nil then medals.dse = "gold"
			elseif string.find(achCurrent, "Infestation") ~= nil then medals.inf = "gold"
			elseif string.find(achCurrent, "Ether")       ~= nil then medals.ee  = "gold"
			elseif string.find(achCurrent, "Outpost")     ~= nil then medals.m13 = "gold"		
			end
		end
	end
	
	local expWnd = mainForm:FindChild("Expeditions")
	if expWnd == nil then
		Apollo.AddAddonErrorText(self, "Could not load the expeditions sub-window for some reason.")
		return
	end
	
	local txtMedal = expWnd:FindChild("F0"):FindChild("Medal")
	if medals.f0 == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.f0 == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
	
	txtMedal = expWnd:FindChild("SM"):FindChild("Medal")
	if medals.sm == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.sm == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
	
	txtMedal = expWnd:FindChild("GNT"):FindChild("Medal")
	if medals.gnt == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.gnt == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
	
	txtMedal = expWnd:FindChild("RL"):FindChild("Medal")
	if medals.rl == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.rl == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
	
	txtMedal = expWnd:FindChild("DSE"):FindChild("Medal")
	if medals.dse == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.dse == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
	
	txtMedal = expWnd:FindChild("INF"):FindChild("Medal")
	if medals.inf == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.inf == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
	
	txtMedal = expWnd:FindChild("EE"):FindChild("Medal")
	if medals.ee == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.ee == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
	
	txtMedal = expWnd:FindChild("M13"):FindChild("Medal")
	if medals.m13 == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.m13 == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
end

-- populates adventure medals list
function MedalTracker:DrawAdvMedals(mainForm)
	local medals = {
		wotw = "none",
		tstr = "none",
		cow = "none",
		tmt = "none",
		bob = "none"
	}
	
	for idx = 1, #tDoneAdventures do
    	local achCurrent = tDoneAdventures[idx]
		MedalTracker:Debug(achCurrent)
		if string.find(achCurrent,     "Riddance")    ~= nil and medals.wotw ~= "gold" and medals.wotw ~= "silver" then medals.wotw = "bronze"
		elseif string.find(achCurrent, "Defender")    ~= nil and medals.tstr ~= "gold" and medals.tstr ~= "silver" then medals.tstr = "bronze"
		elseif string.find(achCurrent, "Criminal")    ~= nil and medals.cow  ~= "gold" and medals.cow  ~= "silver" then medals.cow  = "bronze"
		elseif string.find(achCurrent, "Survivalist") ~= nil and medals.tmt  ~= "gold" and medals.tmt  ~= "silver" then medals.tmt  = "bronze"
		elseif string.find(achCurrent, "Competitor")  ~= nil and medals.bob  ~= "gold" and medals.bob  ~= "silver" then medals.bob  = "bronze"
		-- silver
		elseif string.find(achCurrent, "Masher")    ~= nil and medals.wotw ~= "gold" then medals.wotw = "silver"
		elseif string.find(achCurrent, "Guardian")  ~= nil and medals.tstr ~= "gold" then medals.tstr = "silver"
		elseif string.find(achCurrent, "Crimelord") ~= nil and medals.cow  ~= "gold" then medals.cow  = "silver"
		elseif string.find(achCurrent, "Trailhand") ~= nil and medals.tmt  ~= "gold" then medals.tmt  = "silver"
		elseif string.find(achCurrent, "Assassin")  ~= nil and medals.bob  ~= "gold" then medals.bob  = "silver"
		-- bronze
		elseif string.find(achCurrent, "Skeech")    ~= nil then medals.pa   = "gold"
		elseif string.find(achCurrent, "Decorated") ~= nil then medals.tstr = "gold"
		elseif string.find(achCurrent, "Don")       ~= nil then medals.cow  = "gold"
		elseif string.find(achCurrent, "Caravan")   ~= nil then medals.tmt  = "gold"
		elseif string.find(achCurrent, "Bay")       ~= nil then medals.bob  = "gold"
		end
	end
	
	
	local advWnd = mainForm:FindChild("Adventures")
	if advWnd == nil then
		Apollo.AddAddonErrorText(self, "Could not load the adventures sub-window for some reason.")
		return
	end
	
	local txtMedal = advWnd:FindChild("WOTW"):FindChild("Medal")
	if medals.wotw == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.wotw == "silver" then 
		txtMedal:SetText(tMedals.silver)
		txtMedal:SetTextColor(tColours.silver)
	elseif medals.wotw == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
	
	local txtMedal = advWnd:FindChild("TSTR"):FindChild("Medal")
	if medals.tstr == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.tstr == "silver" then 
		txtMedal:SetText(tMedals.silver)
		txtMedal:SetTextColor(tColours.silver)
	elseif medals.tstr == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
	
	local txtMedal = advWnd:FindChild("COW"):FindChild("Medal")
	if medals.cow  == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.cow  == "silver" then 
		txtMedal:SetText(tMedals.silver)
		txtMedal:SetTextColor(tColours.silver)
	elseif medals.cow  == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
	
	local txtMedal = advWnd:FindChild("TMT"):FindChild("Medal")
	if medals.tmt  == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.tmt  == "silver" then 
		txtMedal:SetText(tMedals.silver)
		txtMedal:SetTextColor(tColours.silver)
	elseif medals.tmt  == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
	
	local txtMedal = advWnd:FindChild("BOB"):FindChild("Medal")
	if medals.bob == "gold" then 
		txtMedal:SetText(tMedals.gold)
		txtMedal:SetTextColor(tColours.gold)
	elseif medals.bob == "silver" then 
		txtMedal:SetText(tMedals.silver)
		txtMedal:SetTextColor(tColours.silver)
	elseif medals.bob == "bronze" then 
		txtMedal:SetText(tMedals.bronze)
		txtMedal:SetTextColor(tColours.bronze)
	else
		txtMedal:SetText(tMedals.none)
		txtMedal:SetTextColor(tColours.none)
	end
end

-----------------------------------------------------------------------------------------------
-- MedalTrackerForm Functions
-----------------------------------------------------------------------------------------------
-- when the Cancel button is clicked
function MedalTracker:OnCancel()
	self.wndMain:Close() -- hide the window
end


function MedalTracker:OnReloadMedals( wndHandler, wndControl, eMouseButton )
	MedalTracker:GetAllMedals()
	MedalTracker:DrawAllMedals(wndHandler:GetParent())
end

-----------------------------------------------------------------------------------------------
-- MedalTracker Instance
-----------------------------------------------------------------------------------------------
local MedalTrackerInst = MedalTracker:new()
MedalTrackerInst:Init()
